viewmask
========
A Python package and CLI to view XML annotations and NumPy masks.

|made-with-python|
|made-with-sphinx-doc|
|PyPI license|
|PyPI version fury.io|
|Documentation Status|

.. |made-with-python| image:: https://img.shields.io/badge/Made%20with-Python-1f425f.svg
   :target: https://www.python.org/

.. |made-with-sphinx-doc| image:: https://img.shields.io/badge/Made%20with-Sphinx-1f425f.svg
  :target: https://www.sphinx-doc.org/

.. |PyPI version fury.io| image:: https://badge.fury.io/py/viewmask.svg
   :target: https://pypi.python.org/pypi/viewmask/

.. |PyPI license| image:: https://img.shields.io/pypi/l/viewmask.svg
  :target: https://pypi.python.org/pypi/viewmask/

.. |Documentation Status| image:: https://readthedocs.org/projects/viewmask/badge/?version=latest
   :target: https://viewmask.readthedocs.io/?badge=latest
